# Compiling and installing casadi on Apple Silicon Macs.

The package ```casadi``` is currently not available as a pre-compiled package for Apple Silicon. To run the code needed in hand-in 2 and the extra exercise in hand-in 3 there are two options:
1. Run in emulation mode with Rosetta, then the available intel version can be installed
2. Compile ```casadi``` from source.

I have prepared a build-script ```build_casadi_tsfs12.sh``` to help you if you choose option 2.

## Compiling ```casadi``` from source
**Before you start**: You need some software pre-installed
* Homebrew package manager (https://brew.sh)
* Python (https://www.python.org). The system python can _not_ be used since it does not include development files.

First, make sure the build-script is executable
```
% chmod +x build_casadi.sh 
```
To see the options for the script, run
```
./build_casadi_tsfs12.sh --help
```

To build, there are three steps
1. Install prerequisites for compilation
2. Build ```casadi``` library and install in ```/usr/local/```. This will require a administrator password.
3. Build the python library

This is done by (replace python3.10 with the python you have installed, any version >= 3.8 should work)
```
% ./build_casadi_tsfs12.sh --install-prerequisites  # step 1
% ./build_casadi_tsfs12.sh --build-lib  # step 2
% ./build_casadi_tsfs12.sh --build-python python3.10  # step 3
```
And this should be it! If these commands run without errors you should have necessary libraries installed in ```/usr/local``` and a ```tar.gz``` for the python files (for example ```casadi_310.tar.gz```).

To use the python files, unpack the python files 
```
% tar -xf casadi_310.tar.gz
```
where you want them and set the environment variable ```PYTHONPATH```. Another option (a bit ugly but a simple solution that I use) is to unpack the files directly into the virtual environment you use, and then you don't have to set any environment variables. For example, if you have created a virtual environment in ```<env>```, you do something similar to
```
% tar -xf casadi_310.tar.gz --directory <env>/lib/python3.10/site-packages
```
and then ```casadi``` should be available.

To verify that it works, start a python prompt with ```ipython``` and run a few casadi statements
```
import casadi
x = casadi.SX.sym('x')
print(casadi.gradient(x * casadi.sin(x), x))
```
